"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.raw_classification_request import RawClassificationRequest
from bimdata_api_client.model.raw_definition_request import RawDefinitionRequest
from bimdata_api_client.model.raw_element_request import RawElementRequest
from bimdata_api_client.model.raw_layer_request import RawLayerRequest
from bimdata_api_client.model.raw_material_list_request import RawMaterialListRequest
from bimdata_api_client.model.raw_property_set_request import RawPropertySetRequest
from bimdata_api_client.model.raw_system_request import RawSystemRequest
from bimdata_api_client.model.raw_unit_request import RawUnitRequest
globals()['RawClassificationRequest'] = RawClassificationRequest
globals()['RawDefinitionRequest'] = RawDefinitionRequest
globals()['RawElementRequest'] = RawElementRequest
globals()['RawLayerRequest'] = RawLayerRequest
globals()['RawMaterialListRequest'] = RawMaterialListRequest
globals()['RawPropertySetRequest'] = RawPropertySetRequest
globals()['RawSystemRequest'] = RawSystemRequest
globals()['RawUnitRequest'] = RawUnitRequest
from bimdata_api_client.model.raw_elements_request import RawElementsRequest


class TestRawElementsRequest(unittest.TestCase):
    """RawElementsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRawElementsRequest(self):
        """Test RawElementsRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RawElementsRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.clipping_plane_request import ClippingPlaneRequest
from bimdata_api_client.model.components_parent_request import ComponentsParentRequest
from bimdata_api_client.model.line_request import LineRequest
from bimdata_api_client.model.orthogonal_camera_request import OrthogonalCameraRequest
from bimdata_api_client.model.perspective_camera_request import PerspectiveCameraRequest
from bimdata_api_client.model.pin_request import PinRequest
from bimdata_api_client.model.snapshot_request import SnapshotRequest
globals()['ClippingPlaneRequest'] = ClippingPlaneRequest
globals()['ComponentsParentRequest'] = ComponentsParentRequest
globals()['LineRequest'] = LineRequest
globals()['OrthogonalCameraRequest'] = OrthogonalCameraRequest
globals()['PerspectiveCameraRequest'] = PerspectiveCameraRequest
globals()['PinRequest'] = PinRequest
globals()['SnapshotRequest'] = SnapshotRequest
from bimdata_api_client.model.patched_viewpoint_request import PatchedViewpointRequest


class TestPatchedViewpointRequest(unittest.TestCase):
    """PatchedViewpointRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPatchedViewpointRequest(self):
        """Test PatchedViewpointRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PatchedViewpointRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.folder_without_children_request import FolderWithoutChildrenRequest


class TestFolderWithoutChildrenRequest(unittest.TestCase):
    """FolderWithoutChildrenRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFolderWithoutChildrenRequest(self):
        """Test FolderWithoutChildrenRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = FolderWithoutChildrenRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from bimdata_api_client.api_client import ApiClient

# import Configuration
from bimdata_api_client.configuration import Configuration

# import exceptions
from bimdata_api_client.exceptions import OpenApiException
from bimdata_api_client.exceptions import ApiAttributeError
from bimdata_api_client.exceptions import ApiTypeError
from bimdata_api_client.exceptions import ApiValueError
from bimdata_api_client.exceptions import ApiKeyError
from bimdata_api_client.exceptions import ApiException



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from bimdata_api_client.api_client import ApiClient, Endpoint as _Endpoint
from bimdata_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from bimdata_api_client.model.invitation import Invitation


class SsoApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.accept_invitation_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/identity-provider/invitation/{id}/accept',
                'operation_id': 'accept_invitation',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_user_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/identity-provider/user',
                'operation_id': 'delete_user',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.deny_invitation_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/identity-provider/invitation/{id}/deny',
                'operation_id': 'deny_invitation',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_invitation_endpoint = _Endpoint(
            settings={
                'response_type': (Invitation,),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/identity-provider/invitation/{id}',
                'operation_id': 'get_invitation',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_invitations_endpoint = _Endpoint(
            settings={
                'response_type': ([Invitation],),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/identity-provider/invitation',
                'operation_id': 'get_invitations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'status',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'status',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('status',): {

                        "A": "A",
                        "D": "D",
                        "P": "P"
                    },
                },
                'openapi_types': {
                    'status':
                        (str,),
                },
                'attribute_map': {
                    'status': 'status',
                },
                'location_map': {
                    'status': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def accept_invitation(
        self,
        id,
        **kwargs
    ):
        """Accept an invitation  # noqa: E501

        If the user already exists, s·he is added to the cloud and projet. If not, we wait their first connection to add them.  Required scopes: org:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.accept_invitation(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (int): A unique integer value identifying this invitation.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.accept_invitation_endpoint.call_with_http_info(**kwargs)

    def delete_user(
        self,
        **kwargs
    ):
        """Delete user from BIMData  # noqa: E501

        Delete the user and all clouds where the user is alone  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_user(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.delete_user_endpoint.call_with_http_info(**kwargs)

    def deny_invitation(
        self,
        id,
        **kwargs
    ):
        """Deny an invitation  # noqa: E501

        The invitation status change to DENIED and the user is not added to the cloud. You can accept an invitation previously denied  Required scopes: org:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.deny_invitation(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (int): A unique integer value identifying this invitation.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.deny_invitation_endpoint.call_with_http_info(**kwargs)

    def get_invitation(
        self,
        id,
        **kwargs
    ):
        """Retrieve an invitation  # noqa: E501

        Retrieve all invitations of your identity provider  Required scopes: org:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_invitation(id, async_req=True)
        >>> result = thread.get()

        Args:
            id (int): A unique integer value identifying this invitation.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Invitation
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['id'] = \
            id
        return self.get_invitation_endpoint.call_with_http_info(**kwargs)

    def get_invitations(
        self,
        **kwargs
    ):
        """Retrieve all invitations  # noqa: E501

        Retrieve all invitations of your identity provider  Required scopes: org:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_invitations(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            status (str):          A: Accepted         D: Denied         P: Pending         . [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [Invitation]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_invitations_endpoint.call_with_http_info(**kwargs)




"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.checker_api import CheckerApi  # noqa: E501


class TestCheckerApi(unittest.TestCase):
    """CheckerApi unit test stubs"""

    def setUp(self):
        self.api = CheckerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_checker(self):
        """Test case for create_checker

        Create a checker to a model  # noqa: E501
        """
        pass

    def test_create_checker_result(self):
        """Test case for create_checker_result

        Create a CheckerResult  # noqa: E501
        """
        pass

    def test_create_checkplan(self):
        """Test case for create_checkplan

        Create a Checkplan  # noqa: E501
        """
        pass

    def test_create_rule(self):
        """Test case for create_rule

        Create a Rule  # noqa: E501
        """
        pass

    def test_create_rule_component(self):
        """Test case for create_rule_component

        Create a RuleComponent  # noqa: E501
        """
        pass

    def test_create_ruleset(self):
        """Test case for create_ruleset

        Create a Ruleset  # noqa: E501
        """
        pass

    def test_delete_checker(self):
        """Test case for delete_checker

        Delete a checker of a model  # noqa: E501
        """
        pass

    def test_delete_checker_result(self):
        """Test case for delete_checker_result

        Delete a CheckerResult  # noqa: E501
        """
        pass

    def test_delete_checkplan(self):
        """Test case for delete_checkplan

        Delete a Checkplan  # noqa: E501
        """
        pass

    def test_delete_rule(self):
        """Test case for delete_rule

        Delete a Rule  # noqa: E501
        """
        pass

    def test_delete_rule_component(self):
        """Test case for delete_rule_component

        Delete a RuleComponent  # noqa: E501
        """
        pass

    def test_delete_ruleset(self):
        """Test case for delete_ruleset

        Delete a Ruleset  # noqa: E501
        """
        pass

    def test_get_checker(self):
        """Test case for get_checker

        Retrieve a checker of a model  # noqa: E501
        """
        pass

    def test_get_checker_result(self):
        """Test case for get_checker_result

        Retrieve one CheckerResult  # noqa: E501
        """
        pass

    def test_get_checker_results(self):
        """Test case for get_checker_results

        Retrieve all CheckerResults  # noqa: E501
        """
        pass

    def test_get_checkers(self):
        """Test case for get_checkers

        Retrieve all checkers of a model  # noqa: E501
        """
        pass

    def test_get_checkplan(self):
        """Test case for get_checkplan

        Retrieve one Checkplan  # noqa: E501
        """
        pass

    def test_get_checkplans(self):
        """Test case for get_checkplans

        Retrieve all Checkplans  # noqa: E501
        """
        pass

    def test_get_rule(self):
        """Test case for get_rule

        Retrieve one Rule  # noqa: E501
        """
        pass

    def test_get_rule_component(self):
        """Test case for get_rule_component

        Retrieve one RuleComponent  # noqa: E501
        """
        pass

    def test_get_rule_components(self):
        """Test case for get_rule_components

        Retrieve all RuleComponents  # noqa: E501
        """
        pass

    def test_get_rules(self):
        """Test case for get_rules

        Retrieve all Rules  # noqa: E501
        """
        pass

    def test_get_ruleset(self):
        """Test case for get_ruleset

        Retrieve one Ruleset  # noqa: E501
        """
        pass

    def test_get_rulesets(self):
        """Test case for get_rulesets

        Retrieve all Rulesets  # noqa: E501
        """
        pass

    def test_launch_new_check(self):
        """Test case for launch_new_check

        Launch a new check on the model  # noqa: E501
        """
        pass

    def test_update_checker(self):
        """Test case for update_checker

        Update some fields of a checker of a model  # noqa: E501
        """
        pass

    def test_update_checker_result(self):
        """Test case for update_checker_result

        Update some fields of a CheckerResult  # noqa: E501
        """
        pass

    def test_update_checkplan(self):
        """Test case for update_checkplan

        Update some fields of a Checkplan  # noqa: E501
        """
        pass

    def test_update_rule(self):
        """Test case for update_rule

        Update some fields of a Rule  # noqa: E501
        """
        pass

    def test_update_rule_component(self):
        """Test case for update_rule_component

        Update some fields of a RuleComponent  # noqa: E501
        """
        pass

    def test_update_ruleset(self):
        """Test case for update_ruleset

        Update some fields of a Ruleset  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.marketplace_app_image import MarketplaceAppImage
from bimdata_api_client.model.public_organization import PublicOrganization
from bimdata_api_client.model.user import User
globals()['MarketplaceAppImage'] = MarketplaceAppImage
globals()['PublicOrganization'] = PublicOrganization
globals()['User'] = User
from bimdata_api_client.model.marketplace_app import MarketplaceApp


class TestMarketplaceApp(unittest.TestCase):
    """MarketplaceApp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMarketplaceApp(self):
        """Test MarketplaceApp"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MarketplaceApp()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.bcf_api import BcfApi  # noqa: E501


class TestBcfApi(unittest.TestCase):
    """BcfApi unit test stubs"""

    def setUp(self):
        self.api = BcfApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_comment(self):
        """Test case for create_comment

        Create a comment  # noqa: E501
        """
        pass

    def test_create_extension_label(self):
        """Test case for create_extension_label

        Create a Label  # noqa: E501
        """
        pass

    def test_create_extension_priority(self):
        """Test case for create_extension_priority

        Create a Priority  # noqa: E501
        """
        pass

    def test_create_extension_stage(self):
        """Test case for create_extension_stage

        Create a Stage  # noqa: E501
        """
        pass

    def test_create_extension_status(self):
        """Test case for create_extension_status

        Create a TopicStatus  # noqa: E501
        """
        pass

    def test_create_extension_type(self):
        """Test case for create_extension_type

        Create a TopicType  # noqa: E501
        """
        pass

    def test_create_full_topic(self):
        """Test case for create_full_topic

        Create a Topic with viewpoints and comments  # noqa: E501
        """
        pass

    def test_create_topic(self):
        """Test case for create_topic

        Create a topic  # noqa: E501
        """
        pass

    def test_create_viewpoint(self):
        """Test case for create_viewpoint

        Create a Viewpoint  # noqa: E501
        """
        pass

    def test_delete_comment(self):
        """Test case for delete_comment

        Delete a comment  # noqa: E501
        """
        pass

    def test_delete_extension_label(self):
        """Test case for delete_extension_label

        Delete a Label  # noqa: E501
        """
        pass

    def test_delete_extension_priority(self):
        """Test case for delete_extension_priority

        Delete a Priority  # noqa: E501
        """
        pass

    def test_delete_extension_stage(self):
        """Test case for delete_extension_stage

        Delete a Stage  # noqa: E501
        """
        pass

    def test_delete_extension_status(self):
        """Test case for delete_extension_status

        Delete a TopicStatus  # noqa: E501
        """
        pass

    def test_delete_extension_type(self):
        """Test case for delete_extension_type

        Delete a TopicType  # noqa: E501
        """
        pass

    def test_delete_topic(self):
        """Test case for delete_topic

        Delete a topic  # noqa: E501
        """
        pass

    def test_delete_viewpoint(self):
        """Test case for delete_viewpoint

        Delete a Viewpoint  # noqa: E501
        """
        pass

    def test_download_bcf_export(self):
        """Test case for download_bcf_export

        Export project's topics in bcf-xml format  # noqa: E501
        """
        pass

    def test_full_update_bcf_project(self):
        """Test case for full_update_bcf_project

        Update all fields of a BCF project  # noqa: E501
        """
        pass

    def test_full_update_comment(self):
        """Test case for full_update_comment

        Update all fields of a comment  # noqa: E501
        """
        pass

    def test_full_update_full_topic(self):
        """Test case for full_update_full_topic

        Update all fields of a topic  # noqa: E501
        """
        pass

    def test_full_update_topic(self):
        """Test case for full_update_topic

        Update all fields of a topic  # noqa: E501
        """
        pass

    def test_full_update_viewpoint(self):
        """Test case for full_update_viewpoint

        Update all fields of a Viewpoint  # noqa: E501
        """
        pass

    def test_get_bcf_project(self):
        """Test case for get_bcf_project

        Retrieve a BCF project  # noqa: E501
        """
        pass

    def test_get_bcf_projects(self):
        """Test case for get_bcf_projects

        Retrieve all BCF projects  # noqa: E501
        """
        pass

    def test_get_colorings(self):
        """Test case for get_colorings

        Retrieve all colorings of a viewpoint  # noqa: E501
        """
        pass

    def test_get_comment(self):
        """Test case for get_comment

        Retrieve a comment  # noqa: E501
        """
        pass

    def test_get_comments(self):
        """Test case for get_comments

        Retrieve all comments  # noqa: E501
        """
        pass

    def test_get_detailed_extensions(self):
        """Test case for get_detailed_extensions

        Retrieve project detailed extensions  # noqa: E501
        """
        pass

    def test_get_extensions(self):
        """Test case for get_extensions

        Retrieve project extensions  # noqa: E501
        """
        pass

    def test_get_full_topic(self):
        """Test case for get_full_topic

        Retrieve a full topic  # noqa: E501
        """
        pass

    def test_get_full_topics(self):
        """Test case for get_full_topics

        Retrieve all full topics  # noqa: E501
        """
        pass

    def test_get_selections(self):
        """Test case for get_selections

        Retrieve all selections of a viewpoint  # noqa: E501
        """
        pass

    def test_get_snapshot(self):
        """Test case for get_snapshot

        Retrieve the viewpoint' snapshot  # noqa: E501
        """
        pass

    def test_get_topic(self):
        """Test case for get_topic

        Retrieve a topic  # noqa: E501
        """
        pass

    def test_get_topic_viewpoints(self):
        """Test case for get_topic_viewpoints

        Retrieve all viewpoints attached to the topic  # noqa: E501
        """
        pass

    def test_get_topics(self):
        """Test case for get_topics

        Retrieve all topics  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get current user info  # noqa: E501
        """
        pass

    def test_get_viewpoint(self):
        """Test case for get_viewpoint

        Retrieve a Viewpoint  # noqa: E501
        """
        pass

    def test_get_viewpoints(self):
        """Test case for get_viewpoints

        Retrieve all Viewpoints of a topic  # noqa: E501
        """
        pass

    def test_get_visibilities(self):
        """Test case for get_visibilities

        Retrieve all visibilities of a viewpoint  # noqa: E501
        """
        pass

    def test_import_bcf(self):
        """Test case for import_bcf

        Import bcf-xml format into this project  # noqa: E501
        """
        pass

    def test_update_bcf_project(self):
        """Test case for update_bcf_project

        Update some fields of a BCF project  # noqa: E501
        """
        pass

    def test_update_comment(self):
        """Test case for update_comment

        Update some fields of a comment  # noqa: E501
        """
        pass

    def test_update_extension_label(self):
        """Test case for update_extension_label

        Update a Label  # noqa: E501
        """
        pass

    def test_update_extension_priority(self):
        """Test case for update_extension_priority

        Update a Priority  # noqa: E501
        """
        pass

    def test_update_extension_stage(self):
        """Test case for update_extension_stage

        Update a Stage  # noqa: E501
        """
        pass

    def test_update_extension_status(self):
        """Test case for update_extension_status

        Update a TopicStatus  # noqa: E501
        """
        pass

    def test_update_extension_type(self):
        """Test case for update_extension_type

        Update a TopicType  # noqa: E501
        """
        pass

    def test_update_full_topic(self):
        """Test case for update_full_topic

        Update some fields of a topic  # noqa: E501
        """
        pass

    def test_update_topic(self):
        """Test case for update_topic

        Update some fields of a topic  # noqa: E501
        """
        pass

    def test_update_viewpoint(self):
        """Test case for update_viewpoint

        Update some fields of a Viewpoint  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BIMData API

    BIMData API documentation  # noqa: E501

    OpenAPI spec version: v1
    Contact: contact@bimdata.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301
from os import path
from io import open

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

NAME = "bimdata-api-client"
VERSION = "9.6.8"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools


REQUIRES = [
    "certifi >= 14.05.14",
    "six >= 1.10",
    "python_dateutil >= 2.5.3",
    "setuptools >= 21.0.0",
    "urllib3 >= 1.15.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="BIMData API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="BIMData.io",
    author_email="contact@bimdata.io",
    url="https://github.com/bimdata/python-api-client",
    keywords=["Swagger", "BIMData API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
)



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.webhook_api import WebhookApi  # noqa: E501


class TestWebhookApi(unittest.TestCase):
    """WebhookApi unit test stubs"""

    def setUp(self):
        self.api = WebhookApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_web_hook(self):
        """Test case for create_web_hook

        Create a new Webhook  # noqa: E501
        """
        pass

    def test_delete_web_hook(self):
        """Test case for delete_web_hook

        Delete a webhook  # noqa: E501
        """
        pass

    def test_get_web_hook(self):
        """Test case for get_web_hook

        Retrieve one configured webhook  # noqa: E501
        """
        pass

    def test_get_web_hooks(self):
        """Test case for get_web_hooks

        Retrieve all configured webhooks  # noqa: E501
        """
        pass

    def test_ping_web_hook(self):
        """Test case for ping_web_hook

        Test a webhook  # noqa: E501
        """
        pass

    def test_update_web_hook(self):
        """Test case for update_web_hook

        Update some field of a webhook  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.collaboration_api import CollaborationApi  # noqa: E501


class TestCollaborationApi(unittest.TestCase):
    """CollaborationApi unit test stubs"""

    def setUp(self):
        self.api = CollaborationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_user_invitation(self):
        """Test case for accept_user_invitation

        Accept an invitation  # noqa: E501
        """
        pass

    def test_accept_validation(self):
        """Test case for accept_validation

        Accept a validation  # noqa: E501
        """
        pass

    def test_add_document_tag(self):
        """Test case for add_document_tag

        Add a tag to a document  # noqa: E501
        """
        pass

    def test_add_group_member(self):
        """Test case for add_group_member

        Add a user to a group  # noqa: E501
        """
        pass

    def test_cancel_cloud_user_invitation(self):
        """Test case for cancel_cloud_user_invitation

        Cancel a pending invitation  # noqa: E501
        """
        pass

    def test_cancel_project_user_invitation(self):
        """Test case for cancel_project_user_invitation

        Cancel a pending invitation  # noqa: E501
        """
        pass

    def test_check_access(self):
        """Test case for check_access

        Check app access from cloud  # noqa: E501
        """
        pass

    def test_close_visa(self):
        """Test case for close_visa

        Close a visa of a document  # noqa: E501
        """
        pass

    def test_create_classification(self):
        """Test case for create_classification

        Create a classification  # noqa: E501
        """
        pass

    def test_create_cloud(self):
        """Test case for create_cloud

        Create a cloud  # noqa: E501
        """
        pass

    def test_create_demo(self):
        """Test case for create_demo

        Create a Demo project in a cloud  # noqa: E501
        """
        pass

    def test_create_dms_tree(self):
        """Test case for create_dms_tree

        Create a complete DMS tree  # noqa: E501
        """
        pass

    def test_create_document(self):
        """Test case for create_document

        Create a document  # noqa: E501
        """
        pass

    def test_create_folder(self):
        """Test case for create_folder

        Create a folder  # noqa: E501
        """
        pass

    def test_create_manage_group(self):
        """Test case for create_manage_group

        Create a group  # noqa: E501
        """
        pass

    def test_create_project(self):
        """Test case for create_project

        Create a project  # noqa: E501
        """
        pass

    def test_create_project_access_token(self):
        """Test case for create_project_access_token

        Create a token for this project  # noqa: E501
        """
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Create a tag  # noqa: E501
        """
        pass

    def test_create_validation(self):
        """Test case for create_validation

        Add a validation to a visa  # noqa: E501
        """
        pass

    def test_create_visa(self):
        """Test case for create_visa

        Create a visa  # noqa: E501
        """
        pass

    def test_create_visa_comment(self):
        """Test case for create_visa_comment

        Add a comment  # noqa: E501
        """
        pass

    def test_delete_all_document_history(self):
        """Test case for delete_all_document_history

        Delete all document history  # noqa: E501
        """
        pass

    def test_delete_classification(self):
        """Test case for delete_classification

        Delete a classification  # noqa: E501
        """
        pass

    def test_delete_cloud(self):
        """Test case for delete_cloud

        Delete a cloud  # noqa: E501
        """
        pass

    def test_delete_cloud_user(self):
        """Test case for delete_cloud_user

        Remove a user from a cloud  # noqa: E501
        """
        pass

    def test_delete_document(self):
        """Test case for delete_document

        Delete the document  # noqa: E501
        """
        pass

    def test_delete_document_tag(self):
        """Test case for delete_document_tag

        Delete a tag from a document  # noqa: E501
        """
        pass

    def test_delete_folder(self):
        """Test case for delete_folder

        Delete a folder  # noqa: E501
        """
        pass

    def test_delete_group_member(self):
        """Test case for delete_group_member

        Delete a user from a group  # noqa: E501
        """
        pass

    def test_delete_manage_group(self):
        """Test case for delete_manage_group

        Delete a group  # noqa: E501
        """
        pass

    def test_delete_project(self):
        """Test case for delete_project

        Delete a project  # noqa: E501
        """
        pass

    def test_delete_project_access_token(self):
        """Test case for delete_project_access_token

        Delete a token  # noqa: E501
        """
        pass

    def test_delete_project_user(self):
        """Test case for delete_project_user

        Remove a user from a project  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Delete the tag  # noqa: E501
        """
        pass

    def test_delete_validation(self):
        """Test case for delete_validation

        Remove a validation  # noqa: E501
        """
        pass

    def test_delete_visa(self):
        """Test case for delete_visa

        Remove a visa  # noqa: E501
        """
        pass

    def test_delete_visa_comment(self):
        """Test case for delete_visa_comment

        Remove a comment  # noqa: E501
        """
        pass

    def test_deny_user_invitation(self):
        """Test case for deny_user_invitation

        Deny an invitation  # noqa: E501
        """
        pass

    def test_deny_validation(self):
        """Test case for deny_validation

        Deny a validation  # noqa: E501
        """
        pass

    def test_get_classification(self):
        """Test case for get_classification

        Retrieve a classification  # noqa: E501
        """
        pass

    def test_get_classifications(self):
        """Test case for get_classifications

        Retrieve all classifications  # noqa: E501
        """
        pass

    def test_get_cloud(self):
        """Test case for get_cloud

        Retrieve one cloud  # noqa: E501
        """
        pass

    def test_get_cloud_invitations(self):
        """Test case for get_cloud_invitations

        Retrieve all pending invitations in the cloud  # noqa: E501
        """
        pass

    def test_get_cloud_size(self):
        """Test case for get_cloud_size

        Get size of the cloud  # noqa: E501
        """
        pass

    def test_get_cloud_user(self):
        """Test case for get_cloud_user

        Retrieve a user in a cloud  # noqa: E501
        """
        pass

    def test_get_cloud_users(self):
        """Test case for get_cloud_users

        Retrieve all users in a cloud, or a list with a filter by email  # noqa: E501
        """
        pass

    def test_get_clouds(self):
        """Test case for get_clouds

        Retrieve all clouds  # noqa: E501
        """
        pass

    def test_get_document(self):
        """Test case for get_document

        Retrieve a document  # noqa: E501
        """
        pass

    def test_get_document_histories(self):
        """Test case for get_document_histories

        Retrieve all document histories  # noqa: E501
        """
        pass

    def test_get_documents(self):
        """Test case for get_documents

        Retrieve all documents  # noqa: E501
        """
        pass

    def test_get_folder(self):
        """Test case for get_folder

        Retrieve a folder  # noqa: E501
        """
        pass

    def test_get_folder_project_users(self):
        """Test case for get_folder_project_users

        Retrieve all users in a project with the permission on the folder  # noqa: E501
        """
        pass

    def test_get_folders(self):
        """Test case for get_folders

        Retrieve all folders  # noqa: E501
        """
        pass

    def test_get_group(self):
        """Test case for get_group

        Retrieve a group  # noqa: E501
        """
        pass

    def test_get_groups(self):
        """Test case for get_groups

        Retrieve all groups  # noqa: E501
        """
        pass

    def test_get_manage_group(self):
        """Test case for get_manage_group

        Retrieve a group  # noqa: E501
        """
        pass

    def test_get_manage_groups(self):
        """Test case for get_manage_groups

        Retrieve all groups  # noqa: E501
        """
        pass

    def test_get_project(self):
        """Test case for get_project

        Retrieve a project  # noqa: E501
        """
        pass

    def test_get_project_access_token(self):
        """Test case for get_project_access_token

        Retrieve one token created for this project  # noqa: E501
        """
        pass

    def test_get_project_access_tokens(self):
        """Test case for get_project_access_tokens

        Retrieve all tokens created for this project  # noqa: E501
        """
        pass

    def test_get_project_creator_visas(self):
        """Test case for get_project_creator_visas

        List visas created by user  # noqa: E501
        """
        pass

    def test_get_project_dms_tree(self):
        """Test case for get_project_dms_tree

        Retrieve the complete DMS tree  # noqa: E501
        """
        pass

    def test_get_project_folder_tree_serializers(self):
        """Test case for get_project_folder_tree_serializers

        Retrieve folder tree for all projects  # noqa: E501
        """
        pass

    def test_get_project_invitations(self):
        """Test case for get_project_invitations

        Retrieve all pending invitations in the project  # noqa: E501
        """
        pass

    def test_get_project_size(self):
        """Test case for get_project_size

        Get size of all model files in the project  # noqa: E501
        """
        pass

    def test_get_project_sub_tree(self):
        """Test case for get_project_sub_tree

        Retrieve the complete projects tree of the cloud  # noqa: E501
        """
        pass

    def test_get_project_tree(self):
        """Test case for get_project_tree

        Retrieve the complete DMS tree  # noqa: E501
        """
        pass

    def test_get_project_users(self):
        """Test case for get_project_users

        Retrieve all users in a project, or a list with a filter by email  # noqa: E501
        """
        pass

    def test_get_project_validator_visas(self):
        """Test case for get_project_validator_visas

        List visas where user is a validator  # noqa: E501
        """
        pass

    def test_get_projects(self):
        """Test case for get_projects

        Retrieve all projects  # noqa: E501
        """
        pass

    def test_get_self_projects(self):
        """Test case for get_self_projects

        List current user's projects  # noqa: E501
        """
        pass

    def test_get_self_user(self):
        """Test case for get_self_user

        Get info about the current user  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Retrieve a tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Retrieve all tags  # noqa: E501
        """
        pass

    def test_get_user_invitation(self):
        """Test case for get_user_invitation

        Retrieve an invitation  # noqa: E501
        """
        pass

    def test_get_user_invitations(self):
        """Test case for get_user_invitations

        List user's invitations  # noqa: E501
        """
        pass

    def test_get_validation(self):
        """Test case for get_validation

        Retrieve a validation to a visa  # noqa: E501
        """
        pass

    def test_get_validations(self):
        """Test case for get_validations

        List all validations to a visa  # noqa: E501
        """
        pass

    def test_get_visa(self):
        """Test case for get_visa

        Retrieve a visa of a document  # noqa: E501
        """
        pass

    def test_get_visa_comment(self):
        """Test case for get_visa_comment

        Retrieve a comment  # noqa: E501
        """
        pass

    def test_get_visa_comments(self):
        """Test case for get_visa_comments

        List all comment of a visa  # noqa: E501
        """
        pass

    def test_get_visas(self):
        """Test case for get_visas

        List all visas of a document  # noqa: E501
        """
        pass

    def test_invite_cloud_user(self):
        """Test case for invite_cloud_user

        Invite a cloud administrator  # noqa: E501
        """
        pass

    def test_invite_project_user(self):
        """Test case for invite_project_user

        Invite a project member  # noqa: E501
        """
        pass

    def test_leave_project(self):
        """Test case for leave_project

        Leave the project  # noqa: E501
        """
        pass

    def test_leave_version_document_history(self):
        """Test case for leave_version_document_history

        Leave the history version  # noqa: E501
        """
        pass

    def test_make_head_version_document_history(self):
        """Test case for make_head_version_document_history

        Make the head of the version  # noqa: E501
        """
        pass

    def test_pause_visa(self):
        """Test case for pause_visa

        Pause a visa of a document  # noqa: E501
        """
        pass

    def test_reset_validation(self):
        """Test case for reset_validation

        Reset a validation  # noqa: E501
        """
        pass

    def test_resume_visa(self):
        """Test case for resume_visa

        Resume a visa of a document  # noqa: E501
        """
        pass

    def test_update_classification(self):
        """Test case for update_classification

        Update some fields of a classification  # noqa: E501
        """
        pass

    def test_update_cloud(self):
        """Test case for update_cloud

        Update some fields of a cloud  # noqa: E501
        """
        pass

    def test_update_cloud_user(self):
        """Test case for update_cloud_user

        Change the user role in the cloud  # noqa: E501
        """
        pass

    def test_update_document(self):
        """Test case for update_document

        Update some fields of the document  # noqa: E501
        """
        pass

    def test_update_folder(self):
        """Test case for update_folder

        Update some fields of a folder  # noqa: E501
        """
        pass

    def test_update_group_folder(self):
        """Test case for update_group_folder

        Update the permission of a group on a folder  # noqa: E501
        """
        pass

    def test_update_manage_group(self):
        """Test case for update_manage_group

        Update some fields of a group  # noqa: E501
        """
        pass

    def test_update_project(self):
        """Test case for update_project

        Update some fields of a project  # noqa: E501
        """
        pass

    def test_update_project_access_token(self):
        """Test case for update_project_access_token

        Update some fields of a token  # noqa: E501
        """
        pass

    def test_update_project_user(self):
        """Test case for update_project_user

        Change the user role in the cloud  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Update some fields of the tag  # noqa: E501
        """
        pass

    def test_update_validation(self):
        """Test case for update_validation

        Update the validator of validation  # noqa: E501
        """
        pass

    def test_update_visa(self):
        """Test case for update_visa

        Update some fields of a visa  # noqa: E501
        """
        pass

    def test_update_visa_comment(self):
        """Test case for update_visa_comment

        Update some fields of a comment  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
